import { KindList, Policy } from '../types.ts';

/**
 * Reject events by kind.
 *
 * @example
 * ```ts
 * // Block DMs, likes, and channel messages.
 * kindPolicy({ kinds: [4, 7, 42] });
 * ```
 */
const kindPolicy: Policy<KindList> = ({ event: { id, kind } }, kinds = []) => {
  if (kinds.includes(kind)) {
    return {
      id,
      action: 'reject',
      msg: 'blocked: this event kind is not currently permitted',
    };
  }

  return {
    id,
    action: 'accept',
    msg: '',
  };
};

export default kindPolicy;